# Generated by Django 5.2.7 on 2025-11-11 15:54

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('endoreg_db', '0005_merge_20251111_1003'),
    ]

    operations = [
        migrations.AddField(
            model_name='sensitivemeta',
            name='anonymized_text',
            field=models.TextField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='sensitivemeta',
            name='casenumber',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='sensitivemeta',
            name='examination_time',
            field=models.TimeField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='sensitivemeta',
            name='external_id',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='endoreg_db.patientexternalid'),
        ),
        migrations.AddField(
            model_name='sensitivemeta',
            name='file_path',
            field=models.CharField(blank=True, max_length=1024, null=True),
        ),
        migrations.AddField(
            model_name='sensitivemeta',
            name='text',
            field=models.TextField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='patientexternalid',
            name='external_id',
            field=models.CharField(max_length=255),
        ),
        migrations.AlterField(
            model_name='sensitivemeta',
            name='center',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='endoreg_db.center'),
        ),
        migrations.AlterField(
            model_name='sensitivemeta',
            name='examiners',
            field=models.ManyToManyField(blank=True, help_text='Pseudo-anonymized examiner(s)', to='endoreg_db.examiner'),
        ),
        migrations.AlterField(
            model_name='sensitivemeta',
            name='patient_dob',
            field=models.DateTimeField(blank=True, help_text='Date of birth (can be auto-generated).', null=True),
        ),
        migrations.AddConstraint(
            model_name='patientexternalid',
            constraint=models.UniqueConstraint(fields=('origin', 'external_id'), name='uniq_patient_external_id_per_origin'),
        ),
    ]
