# Generated by Django 5.2.7 on 2025-11-13 09:13

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("endoreg_db", "0007_remove_rule_attribute_dtype_remove_rule_rule_type_and_more"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="event",
            name="event_classification",
        ),
        migrations.RemoveField(
            model_name="organ",
            name="location_choices",
        ),
        migrations.AddField(
            model_name="eventclassification",
            name="event",
            field=models.ForeignKey(default=1, on_delete=django.db.models.deletion.CASCADE, related_name="event_classifications", to="endoreg_db.event"),
            preserve_default=False,
        ),
    ]
