# Generated by Django 5.2.7 on 2025-11-12 15:57

import django.core.validators
import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('endoreg_db', '0006_sensitivemeta_anonymized_text_and_more'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='rule',
            name='attribute_dtype',
        ),
        migrations.RemoveField(
            model_name='rule',
            name='rule_type',
        ),
        migrations.RemoveField(
            model_name='ruleset',
            name='rules',
        ),
        migrations.AddField(
            model_name='numericvaluedistribution',
            name='max_value',
            field=models.FloatField(blank=True, help_text='Upper hard limit for generated values', null=True),
        ),
        migrations.AddField(
            model_name='numericvaluedistribution',
            name='mean',
            field=models.FloatField(blank=True, help_text='Mean used for normal or skewed normal distributions', null=True),
        ),
        migrations.AddField(
            model_name='numericvaluedistribution',
            name='min_value',
            field=models.FloatField(blank=True, help_text='Lower hard limit for generated values', null=True),
        ),
        migrations.AddField(
            model_name='numericvaluedistribution',
            name='skewness',
            field=models.FloatField(blank=True, help_text='Shape parameter for skewed normal distributions', null=True),
        ),
        migrations.AddField(
            model_name='numericvaluedistribution',
            name='std_dev',
            field=models.FloatField(blank=True, help_text='Standard deviation for bell-shaped distributions', null=True),
        ),
        migrations.AlterField(
            model_name='anonymexaminationreport',
            name='file',
            field=models.FileField(blank=True, null=True, upload_to='pdfs'),
        ),
        migrations.AlterField(
            model_name='anonymhistologyreport',
            name='file',
            field=models.FileField(blank=True, null=True, upload_to='pdfs'),
        ),
        migrations.AlterField(
            model_name='rawpdffile',
            name='anonymized_file',
            field=models.FileField(blank=True, null=True, upload_to='pdfs', validators=[django.core.validators.FileExtensionValidator(allowed_extensions=['pdf'])]),
        ),
        migrations.AlterField(
            model_name='rawpdffile',
            name='file',
            field=models.FileField(upload_to='pdfs', validators=[django.core.validators.FileExtensionValidator(allowed_extensions=['pdf'])]),
        ),
        migrations.AlterField(
            model_name='sensitivemeta',
            name='center',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='endoreg_db.center'),
        ),
        migrations.DeleteModel(
            name='RuleAttributeDType',
        ),
        migrations.DeleteModel(
            name='RuleType',
        ),
        migrations.DeleteModel(
            name='Rule',
        ),
        migrations.DeleteModel(
            name='Ruleset',
        ),
    ]
